# -*- coding: utf-8 -*-
import re
import time
from BasePage.BasePage import BasePage
from Config import Config
from Pages.PageManagementPage.PageManagementPage import PageManagementPage


class LoginButtonPage(BasePage):

    def __init__(self, page):
        super().__init__(page)
        """通用属性-外观属性"""
        "# 定位渐变/图片按钮"
        self.gradient_and_picture_button_locator = page.get_by_label("外观", exact=True).locator("use")
        # 定位渐变色按钮
        self.gradient_button_locator = page.get_by_label("外观", exact=True).get_by_title("线性渐变")

        "边框"
        # 定位边框类型的下拉框按钮
        self.frame_type_button_locator = page.get_by_label("外观", exact=True).get_by_placeholder(" ")
        # 定位直线类型
        self.straight_line_frame_locator = page.get_by_role("list").get_by_text("直线")
        # self.straight_line_frame_locator = page.locator("//li[@class='el-select-dropdown__item hover']//div[@class='opt_img']//span")
        # 定位圆点类型
        self.circular_dots_frame_locator = page.get_by_role("list").get_by_text("圆点")
        # 定位虚线类型
        self.dashed_line_frame_locator = page.get_by_role("list").get_by_text("虚线")
        # 定位无边框类型
        self.no_frame_locator = page.get_by_role("list").get_by_text("无", exact=True)
        # 定位宽度输入框
        self.frame_width_locator = page.get_by_label("外观", exact=True).locator("div").filter(has_text=re.compile(r"^边框$")).get_by_role("spinbutton")

        "阴影"
        # 定位外阴影按钮
        self.external_shadow_button_locator = page.get_by_label("外观", exact=True).get_by_title("外阴影")
        # 定位内阴影按钮
        self.internal_shadow_button_locator = page.get_by_label("外观", exact=True).get_by_title("内阴影（可能被内部内容遮挡）")

        "圆角"
        # 定位圆角输入框
        self.rounded_corners_locator = page.get_by_label("外观", exact=True).locator("div").filter(has_text=re.compile(r"^圆角$")).get_by_role("spinbutton")


    def appearance_attribute_set_gradient_color_background(self):
        """
        外观属性：设置渐变色背景
        """
        pmp = PageManagementPage(self.page)
        self._click(pw_locator=self.gradient_and_picture_button_locator)
        self._click(pw_locator=self.gradient_button_locator)  # 点击渐变色按钮
        self._click(pw_locator=self.gradient_button_locator)  # 再次点击，使其关闭弹窗

    def appearance_attribute_set_image_background_stretch_type(self):
        """
        外观属性：设置图片背景，且为拉伸类型
        """
        pmp = PageManagementPage(self.page)
        self._click(pw_locator=self.gradient_and_picture_button_locator)  # 图片背景
        self._click(pw_locator=pmp.add_image_locator)
        self._click(pw_locator=pmp.image_locator)
        self._click(pw_locator=pmp.image_select_button_locator)
        self._click(pw_locator=pmp.image_stretch_type_locator)  # 设置为拉伸类型

    def appearance_attribute_set_image_background_actual_type(self):
        """
        外观属性：设置图片背景，且为实际大小类型
        """
        pmp = PageManagementPage(self.page)
        self._click(pw_locator=self.gradient_and_picture_button_locator)  # 图片背景
        self._click(pw_locator=pmp.add_image_locator)
        self._click(pw_locator=pmp.image_locator)
        self._click(pw_locator=pmp.image_select_button_locator)
        self._click(pw_locator=pmp.image_actual_type_locator)  # 设置为实际大小类型

    def appearance_attribute_set_image_background_cover_type(self):
        """
        外观属性：设置图片背景，且为覆盖类型
        """
        pmp = PageManagementPage(self.page)
        self._click(pw_locator=self.gradient_and_picture_button_locator)  # 图片背景
        self._click(pw_locator=pmp.add_image_locator)  # 定位添加图片按钮
        self._click(pw_locator=pmp.image_locator)
        self._click(pw_locator=pmp.image_select_button_locator)
        self._click(pw_locator=pmp.image_cover_type_locator)  # 设置为覆盖类型

    def appearance_attribute_set_image_background_adapt_type(self):
        """
        外观属性：设置图片背景，且为自适应类型
        """
        pmp = PageManagementPage(self.page)
        self._click(pw_locator=self.gradient_and_picture_button_locator)
        self._click(pw_locator=pmp.add_image_locator)
        self._click(pw_locator=pmp.image_locator)
        self._click(pw_locator=pmp.image_select_button_locator)
        self._click(pw_locator=pmp.image_adapt_type_locator)  # 设置为覆盖类型

    def create_login_button(self):
        """
        拖出登录按钮组件
        :return:
        """
        pmp = PageManagementPage(self.page)
        # 打开组件箱
        self._click(pw_locator=pmp.component_box_locator)
        # 点击登录按钮组件
        self._click(pw_locator=pmp.login_button_component_locator)
        # 拖到画布中
        self._drag_and_drop_to_user_position(pmp.login_button_component_locator, Config.target_point_x,
                                             Config.target_point_y)
        time.sleep(0.5)  # 等待0.5s加载属性栏

    def set_xywh(self):
        """
        拖出登录按钮组件，设置x、y、w、h属性
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()  # 拖出登录按钮组件
        pmp.location_attribute_set_x_axis(300)  # x
        pmp.location_attribute_set_y_axis(400)  # y
        pmp.location_attribute_set_width(400)  # w
        pmp.location_attribute_set_high(200)  # h

    def set_rotation_angle(self):
        """
        拖出登录按钮组件，设置旋转角度
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()
        pmp.location_attribute_set_rotation_angle(45)  # 旋转角度

    def set_lock(self):
        """
        拖出登录按钮组件，设置锁定
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()
        pmp.location_attribute_set_lock()

    def set_solid_color_background(self):
        """
        拖出登录按钮组件，设置纯色背景
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()
        pmp.appearance_attribute_set_solid_color_background()

    def set_gradient_color_background(self):
        """
        拖出登录按钮组件，设置渐变色背景
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()
        self.appearance_attribute_set_gradient_color_background()

    def set_stretch_type_image_background(self):
        """
        拖出登录按钮组件，设置图片背景，且为拉伸类型
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()
        self.appearance_attribute_set_image_background_stretch_type()  # 设置为拉伸类型

    def set_adapt_type_image_background(self):
        """
        拖出登录按钮组件，设置图片背景，且为自适应类型
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()
        time.sleep(0.5)
        self.appearance_attribute_set_image_background_adapt_type()  # 设置为自适应类型

    def set_cover_type_image_background(self):
        """
        拖出登录按钮组件，设置图片背景，且为覆盖类型
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()
        self.appearance_attribute_set_image_background_cover_type()  # 设置为覆盖类型

    def set_actual_type_image_background(self):
        """
        拖出登录按钮组件，设置图片背景，且为实际大小类型
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()
        self.appearance_attribute_set_image_background_actual_type()  # 设置为实际大小类型

    def appearance_attribute_set_frame_width(self, value):
        """
        外观属性：设置边框宽度
        :param value: 边框宽度
        :return:
        """
        self._click(pw_locator=self.frame_width_locator)
        self._fill(value, pw_locator=self.frame_width_locator)  # 边框宽度

    def appearance_attribute_set_straight_line_frame(self):
        """
        外观属性：设置直线边框
        :return:
        """
        self._click(pw_locator=self.frame_type_button_locator)
        self._click(pw_locator=self.straight_line_frame_locator)  # 直线

    def appearance_attribute_set_frame_colour(self):
        """
        外观属性：设置边框颜色
        :return:
        """
        pmp = PageManagementPage(self.page)
        self._click(pw_locator=pmp.frame_colour_locator)
        self._click(pw_locator=pmp.frame_red_colour_locator)
        self._click(pw_locator=pmp.color_selection_window_ok_button_locator)

    def appearance_attribute_set_dashed_line_frame(self):
        """
        外观属性：设置虚线边框
        :return:
        """
        self._click(pw_locator=self.frame_type_button_locator)
        self._click(pw_locator=self.dashed_line_frame_locator)  # 虚线

    def appearance_attribute_set_scircular_dots_frame(self):
        """
        外观属性：设置圆点边框
        :return:
        """
        self._click(pw_locator=self.frame_type_button_locator)
        self._click(pw_locator=self.circular_dots_frame_locator)  # 圆点

    def appearance_attribute_set_no_frame(self):
        """
        外观属性：设置无边框
        :return:
        """
        self._click(pw_locator=self.frame_type_button_locator)
        self._click(pw_locator=self.no_frame_locator)  # 无边框

    def appearance_attribute_set_external_shadow(self):
        """
        外观属性：设置外阴影，颜色默认为红色
        :return:
        """
        pmp = PageManagementPage(self.page)
        self._click(pw_locator=self.external_shadow_button_locator)  # 点击外阴影按钮
        self._click(pw_locator=pmp.external_shadow_ambiguity_locator)  # 设置模糊度
        self._click(pw_locator=pmp.color_selector_for_external_shadows_locator)  # 定位颜色选择器按钮
        self._click(pw_locator=pmp.color_of_external_shadow_locator)  # 设置外阴影颜色，红色
        self._click(pw_locator=pmp.color_selection_window_ok_button_locator)  # 关闭外阴影弹窗

    def appearance_attribute_set_internal_shadow(self):
        """
        外观属性：设置内阴影，颜色默认为绿色
        :return:
        """
        pmp = PageManagementPage(self.page)
        self._click(pw_locator=self.internal_shadow_button_locator)  # 点击内阴影按钮
        self._click(pw_locator=pmp.internal_shadow_ambiguity_locator)  # 设置模糊度
        self._click(pw_locator=pmp.color_selector_for_internal_shadows_locator)  # 定位颜色选择器按钮
        self._click(pw_locator=pmp.color_of_internal_shadow_locator)  # 设置内阴影颜色，绿色
        self._click(pw_locator=pmp.color_selection_window_ok_button_locator)  # 关闭内阴影弹窗

    def appearance_attribute_set_rounded_corners(self, value):
        """
        外观属性：设置圆角弧度
        :param value: 弧度值
        :return:
        """
        self._click(pw_locator=self.rounded_corners_locator)
        self._fill(value, pw_locator=self.rounded_corners_locator)

    def set_straight_line_frame(self):
        """
        拖出登录按钮组件，设置直线边框，宽度为5，颜色为红色
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()  # 拖出登录按钮组件
        self.appearance_attribute_set_frame_width(5)  # 边框宽度
        self.appearance_attribute_set_straight_line_frame()  # 直线
        self.appearance_attribute_set_frame_colour()  # 边框颜色

    def set_dashed_line_frame(self):
        """
        拖出登录按钮组件，设置虚线边框，宽度为5，颜色为红色
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()  # 拖出登录按钮组件
        self.appearance_attribute_set_frame_width(5)  # 边框宽度
        self.appearance_attribute_set_dashed_line_frame()  # 虚线
        self.appearance_attribute_set_frame_colour()  # 边框颜色

    def set_scircular_dots_frame(self):
        """
        拖出登录按钮组件，设置圆点边框，宽度为5，颜色为红色
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()  # 拖出登录按钮组件
        self.appearance_attribute_set_frame_width(5)  # 边框宽度
        self.appearance_attribute_set_scircular_dots_frame()  # 圆点
        self.appearance_attribute_set_frame_colour()  # 边框颜色

    def set_no_frame(self):
        """
        拖出登录按钮组件，设置无边框，宽度为5，颜色为红色
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()  # 拖出登录按钮组件
        self.appearance_attribute_set_frame_width(5)  # 边框宽度
        self.appearance_attribute_set_no_frame()  # 圆点
        self.appearance_attribute_set_frame_colour()  # 边框颜色

    def set_shadow(self):
        """
        拖出登录按钮组件，设置内外阴影
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()  # 拖出登录按钮组件
        self.appearance_attribute_set_external_shadow()
        time.sleep(1)
        self.appearance_attribute_set_internal_shadow()

    def set_rounded_corners(self):
        """
        拖出登录按钮组件，设置圆角
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()  # 拖出登录按钮组件
        self.appearance_attribute_set_rounded_corners(50)

    def set_opacity(self):
        """
        拖出登录按钮组件，设置不透明度
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()  # 拖出登录按钮组件
        pmp.appearance_attribute_set_solid_color_background()
        time.sleep(0.5)
        pmp.appearance_attribute_set_opacity()

    def set_left_aligned(self):
        """
        拖出登录按钮组件，设置左对齐
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()  # 拖出登录按钮组件
        pmp.location_attribute_set_width(400)
        pmp.location_attribute_set_high(200)
        time.sleep(0.5)
        pmp.text_attribute_set_left_aligned()

    def set_center_aligned(self):
        """
        拖出登录按钮组件，设置左对齐
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()  # 拖出登录按钮组件
        pmp.location_attribute_set_width(400)
        pmp.location_attribute_set_high(200)
        time.sleep(0.5)
        pmp.text_attribute_set_center_aligned()

    def set_right_aligned(self):
        """
        拖出登录按钮组件，设置居中对齐
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()  # 拖出登录按钮组件
        pmp.location_attribute_set_width(400)
        pmp.location_attribute_set_high(200)
        time.sleep(0.5)
        pmp.text_attribute_set_right_aligned()

    def set_font_style(self):
        """
        拖出登录按钮组件，设置字号,字体颜色,加粗,斜体,下划线
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()  # 拖出登录按钮组件
        pmp.text_attribute_set_font_size()  # 字号
        time.sleep(0.5)
        pmp.text_attribute_set_font_color()  # 字体颜色
        time.sleep(0.5)
        pmp.text_attribute_set_bold()  # 加粗
        pmp.text_attribute_set_italic()  # 斜体
        pmp.text_attribute_set_underline()  # 下划线

    def set_font_type(self):
        """
        拖出登录按钮组件，设置字体类型,手写体
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()  # 拖出登录按钮组件
        pmp.text_attribute_set_font_size()
        time.sleep(0.5)
        pmp.text_attribute_set_font_type()

    def set_font_distance(self):
        """
        拖出登录按钮组件，设置字距,行高
        :return:
        """
        pmp = PageManagementPage(self.page)
        self.create_login_button()  # 拖出登录按钮组件
        pmp.text_attribute_set_font_size()
        time.sleep(0.5)
        pmp.text_attribute_set_font_distance(40)  # 字距
        pmp.text_attribute_set_font_row_heigh(80)  # 行高