# -*- coding: utf-8 -*-
import os
import time

import allure
import pytest
from playwright.sync_api import expect
from BasePage.BasePage import BasePage
from Common.AllurePretty import PrettyAllure
from Common.ImageComparison import ImageComparisonTool
from Common.ScreenCapture import ScreenCapture
from Config import Config
from Pages.PageManagementPage.PageManagementPage import PageManagementPage
from Utils.ReadYaml import ReadYaml


@allure.epic("CMS2.0UI自动化测试")
@allure.feature("页面管理")
class TestPageManagement:
	"""菜单栏测试用例"""

	@allure.story("工具栏-验证撤销操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_撤销操作_实际图", "工具栏_撤销操作_预期图")])
	def test_toolbar_undo_operation(self, page, create_and_destroy_page, filename, actual_img_name,expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_undo_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证恢复操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_恢复操作_实际图", "工具栏_恢复操作_预期图")])
	def test_toolbar_redo_operation(self, page, create_and_destroy_page, filename, actual_img_name,expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_redo_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证复制粘贴操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_复制粘贴操作_实际图", "工具栏_复制粘贴操作_预期图")])
	def test_toolbar_copy_paste_operation(self, page, create_and_destroy_page, filename, actual_img_name, expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_copy_paste_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证剪切操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_剪切操作_实际图", "工具栏_剪切操作_预期图")])
	def test_toolbar_cut_operation(self, page, create_and_destroy_page, filename, actual_img_name, expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_cut_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证下一层操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_下一层操作_实际图", "工具栏_下一层操作_预期图")])
	def test_toolbar_next_layer_operation(self, page, create_and_destroy_page, filename, actual_img_name, expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_next_layer_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证上一层操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_上一层操作_实际图", "工具栏_上一层操作_预期图")])
	def test_toolbar_upper_layer_operation(self, page, create_and_destroy_page, filename, actual_img_name, expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_upper_layer_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证底层操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_底层操作_实际图", "工具栏_底层操作_预期图")])
	def test_toolbar_under_layer_operation(self, page, create_and_destroy_page, filename, actual_img_name, expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_under_layer_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证顶层操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_顶层操作_实际图", "工具栏_顶层操作_预期图")])
	def test_toolbar_top_layer_operation(self, page, create_and_destroy_page, filename, actual_img_name, expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_top_layer_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证组合操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_组合操作_实际图", "工具栏_组合操作_预期图")])
	def test_toolbar_combination_operation(self, page, create_and_destroy_page, filename, actual_img_name, expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_combination_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证拆分操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_拆分操作_实际图", "工具栏_拆分操作_预期图")])
	def test_toolbar_split_operation(self, page, create_and_destroy_page, filename, actual_img_name, expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_split_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证左侧对齐操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_左侧对齐操作_实际图", "工具栏_左侧对齐操作_预期图")])
	def test_toolbar_left_align_operation(self, page, create_and_destroy_page, filename, actual_img_name, expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_left_align_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证居中对齐操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_居中对齐操作_实际图", "工具栏_居中对齐操作_预期图")])
	def test_toolbar_center_align_operation(self, page, create_and_destroy_page, filename, actual_img_name,expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_center_align_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证右侧对齐操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_右侧对齐操作_实际图", "工具栏_右侧对齐操作_预期图")])
	def test_toolbar_right_align_operation(self, page, create_and_destroy_page, filename, actual_img_name,expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_right_align_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证顶部对齐操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_顶部对齐操作_实际图", "工具栏_顶部对齐操作_预期图")])
	def test_toolbar_top_align_operation(self, page, create_and_destroy_page, filename, actual_img_name,expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_top_align_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证中部对齐操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_中部对齐操作_实际图", "工具栏_中部对齐操作_预期图")])
	def test_toolbar_middle_align_operation(self, page, create_and_destroy_page, filename, actual_img_name,expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_middle_align_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证底部对齐操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_底部对齐操作_实际图", "工具栏_底部对齐操作_预期图")])
	def test_toolbar_under_align_operation(self, page, create_and_destroy_page, filename, actual_img_name,expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_under_align_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证水平对齐操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_水平对齐操作_实际图", "工具栏_水平对齐操作_预期图")])
	def test_toolbar_horizonta_align_operation(self, page, create_and_destroy_page, filename, actual_img_name,expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_horizonta_align_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证垂直对齐操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_垂直对齐操作_实际图", "工具栏_垂直对齐操作_预期图")])
	def test_toolbar_vertical_align_operation(self, page, create_and_destroy_page, filename, actual_img_name,expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_vertical_align_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证等宽对齐操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_等宽对齐操作_实际图", "工具栏_等宽对齐操作_预期图")])
	def test_toolbar_equal_width_operation(self, page, create_and_destroy_page, filename, actual_img_name,expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_equal_width_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证等高对齐操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_等高对齐操作_实际图", "工具栏_等高对齐操作_预期图")])
	def test_toolbar_equal_high_operation(self, page, create_and_destroy_page, filename, actual_img_name,expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_equal_high_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证锁定操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_锁定操作_实际图", "工具栏_锁定操作_预期图")])
	def test_toolbar_lock_operation(self, page, create_and_destroy_page, filename, actual_img_name,expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_lock_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证解锁操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_解锁操作_实际图", "工具栏_解锁操作_预期图")])
	def test_toolbar_unlock_operation(self, page, create_and_destroy_page, filename, actual_img_name,expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_unlock_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证显示操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_显示操作_实际图", "工具栏_显示操作_预期图")])
	def test_toolbar_display_operation(self, page, create_and_destroy_page, filename, actual_img_name,expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_display_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"

	@allure.story("工具栏-验证隐藏操作")
	@pytest.mark.parametrize("filename,actual_img_name,expect_img_name",[("PageManagement", "工具栏_隐藏操作_实际图", "工具栏_隐藏操作_预期图")])
	def test_toolbar_hide_operation(self, page, create_and_destroy_page, filename, actual_img_name,expect_img_name):
		bp = BasePage(page)
		bp._goto_url("画面")
		pmp = PageManagementPage(page)
		pmp.test_hide_operation()
		time.sleep(1)
		result = bp.compare_images(filename, actual_img_name, expect_img_name)
		bp.allure_reports(filename, actual_img_name, expect_img_name)
		assert result, f"页面截图与预期截图不一致"








